# Places

**places** is a django app (using *geodjango*) that allow you to manage
geo-localized places.

It's currently a work in progress app. Cleanup and conversion to py2/py3 are
currently on the roadmap.